import { INotebookTracker, NotebookPanel, NotebookWidgetFactory, NotebookModelFactory } from '@jupyterlab/notebook';
import { Context } from '@jupyterlab/docregistry';
import { ILayoutRestorer, IRouter } from '@jupyterlab/application';
import { ICommandPalette, MainAreaWidget } from '@jupyterlab/apputils';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { IEditorServices } from '@jupyterlab/codeeditor';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
/**
 * The command IDs used by the plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.createNew = 'notebook:create-temp-new';
})(CommandIDs || (CommandIDs = {}));
console.log('cleared ephem');
/**
 * The default notebook factory plugin.
 */
const factory = {
    id: 'jupyterlab-notebook-extension:factory',
    requires: [ICommandPalette, INotebookTracker, IFileBrowserFactory, IEditorServices, IRenderMimeRegistry],
    optional: [ILayoutRestorer, IRouter],
    autoStart: true,
    activate: (app, palette, tracker, browserFactory, editorServices, rendermime, restorer, router) => {
        const { commands } = app;
        console.log('ephemeral_notebooks/src/index.ts:factory:activate:commands:', commands, app);
        // Create a new notebook widget factory.
        const contentFactory = new NotebookPanel.ContentFactory({ editorFactory: editorServices.factoryService.newInlineEditor });
        const widgetFactory = new NotebookWidgetFactory({
            name: 'Temp Notebook',
            fileTypes: ['notebook'],
            modelName: 'temp-notebook',
            preferKernel: false,
            canStartKernel: false,
            rendermime,
            contentFactory,
            mimeTypeService: editorServices.mimeTypeService
        });
        console.log('widget factory', contentFactory, widgetFactory);
        // Register the widget factory.
        app.docRegistry.addWidgetFactory(widgetFactory);
        // Add the command to create a new temporary notebook.
        commands.addCommand(CommandIDs.createNew, {
            label: 'Create New Temporary Notebook',
            execute: async (args) => {
                const modelFactory = new NotebookModelFactory({});
                const context = new Context({
                    manager: app.serviceManager,
                    factory: modelFactory,
                    path: 'temp-notebook.ipynb',
                    kernelPreference: { shouldStart: false, canStart: false }
                });
                const content = new NotebookPanel({
                    context,
                    //@ts-ignore
                    contentFactory,
                    mimeTypeService: editorServices.mimeTypeService,
                    rendermime
                });
                content.title.label = 'Untitled';
                content.title.closable = true;
                const widget = new MainAreaWidget({ content });
                widget.title.label = 'Temporary Notebook';
                app.shell.add(widget, 'main');
                if (args.activate !== false) {
                    app.shell.activateById(widget.id);
                }
                return widget;
            }
        });
        // Add the command to the palette.
        palette.addItem({ command: CommandIDs.createNew, category: 'Notebook' });
    }
};
/**
 * Export the plugins as default.
 */
const plugins = [factory];
export default plugins;
//# sourceMappingURL=index%20copy.js.map