//@ts-nocheck
import { StaticNotebook, INotebookTracker, NotebookPanel, NotebookWidgetFactory, NotebookModelFactory } from '@jupyterlab/notebook';
import { Context } from '@jupyterlab/docregistry';
import { ILayoutRestorer, IRouter } from '@jupyterlab/application';
import { ICommandPalette, MainAreaWidget, SessionContextDialogs } from '@jupyterlab/apputils';
import { IFileBrowserFactory } from '@jupyterlab/filebrowser';
import { IEditorServices } from '@jupyterlab/codeeditor';
import { IRenderMimeRegistry } from '@jupyterlab/rendermime';
import { ILauncher } from '@jupyterlab/launcher';
/**
 * The command IDs used by the plugin.
 */
var CommandIDs;
(function (CommandIDs) {
    CommandIDs.createNew = 'notebook:create-temp-new';
})(CommandIDs || (CommandIDs = {}));
console.log('cleared ephem');
import { nullTranslator } from '@jupyterlab/translation';
import { PageConfig } from '@jupyterlab/coreutils';
import { ToolbarItems as DocToolbarItems } from '@jupyterlab/docmanager-extension';
const FACTORY = 'Notebook';
/**
 * Activate the notebook widget factory.
 */
function activateWidgetFactory(app, contentFactory, editorServices, rendermime, toolbarRegistry, settingRegistry, sessionContextDialogs_, translator_) {
    const translator = translator_ !== null && translator_ !== void 0 ? translator_ : nullTranslator;
    const sessionContextDialogs = sessionContextDialogs_ !== null && sessionContextDialogs_ !== void 0 ? sessionContextDialogs_ : new SessionContextDialogs({ translator });
    const preferKernelOption = PageConfig.getOption('notebookStartsKernel');
    // If the option is not set, assume `true`
    const preferKernelValue = preferKernelOption === '' || preferKernelOption.toLowerCase() === 'true';
    const { commands } = app;
    let toolbarFactory;
    // Register notebook toolbar widgets
    toolbarRegistry.addFactory(FACTORY, 'save', panel => DocToolbarItems.createSaveButton(commands, panel.context.fileChanged));
    toolbarRegistry.addFactory(FACTORY, 'cellType', panel => ToolbarItems.createCellTypeItem(panel, translator));
    toolbarRegistry.addFactory(FACTORY, 'kernelName', panel => Toolbar.createKernelNameItem(panel.sessionContext, sessionContextDialogs, translator));
    toolbarRegistry.addFactory(FACTORY, 'executionProgress', panel => {
        const loadingSettings = settingRegistry === null || settingRegistry === void 0 ? void 0 : settingRegistry.load(trackerPlugin.id);
        const indicator = ExecutionIndicator.createExecutionIndicatorItem(panel, translator, loadingSettings);
        void (loadingSettings === null || loadingSettings === void 0 ? void 0 : loadingSettings.then(settings => {
            panel.disposed.connect(() => {
                settings.dispose();
            });
        }));
        return indicator;
    });
    if (settingRegistry) {
        // Create the factory
        toolbarFactory = createToolbarFactory(toolbarRegistry, settingRegistry, FACTORY, PANEL_SETTINGS, translator);
    }
    const trans = translator.load('jupyterlab');
    const factory = new NotebookWidgetFactory({
        name: FACTORY,
        label: trans.__('Notebook'),
        fileTypes: ['notebook'],
        modelName: 'notebook',
        defaultFor: ['notebook'],
        preferKernel: preferKernelValue,
        canStartKernel: true,
        rendermime,
        contentFactory,
        editorConfig: StaticNotebook.defaultEditorConfig,
        notebookConfig: StaticNotebook.defaultNotebookConfig,
        mimeTypeService: editorServices.mimeTypeService,
        toolbarFactory,
        translator
    });
    app.docRegistry.addWidgetFactory(factory);
    return factory;
}
/**
 * The default notebook factory plugin.
 */
const factory = {
    id: 'jupyterlab-notebook-extension:factory',
    requires: [ICommandPalette, INotebookTracker, IFileBrowserFactory, IEditorServices, IRenderMimeRegistry, ILauncher],
    optional: [ILayoutRestorer, IRouter],
    autoStart: true,
    activate: (app, palette, tracker, browserFactory, editorServices, rendermime, launcher, restorer, router) => {
        const { commands } = app;
        console.log('ephemeral_notebooks/src/index.ts:factory:activate:commands:', commands, app);
        // Create a new notebook widget factory.
        const contentFactory = new NotebookPanel.ContentFactory({ editorFactory: editorServices.factoryService.newInlineEditor });
        const widgetFactory = new NotebookWidgetFactory({
            name: 'Temp Notebook',
            fileTypes: ['notebook'],
            modelName: 'temp-notebook',
            preferKernel: false,
            canStartKernel: false,
            rendermime,
            contentFactory,
            mimeTypeService: editorServices.mimeTypeService
        });
        console.log('widget factory', contentFactory, widgetFactory);
        // Register the widget factory.
        app.docRegistry.addWidgetFactory(widgetFactory);
        // Add the command to create a new temporary notebook.
        commands.addCommand(CommandIDs.createNew, {
            label: 'Create New Temporary Notebook',
            execute: async (args) => {
                const modelFactory = new NotebookModelFactory({});
                const context = new Context({
                    manager: app.serviceManager,
                    factory: modelFactory,
                    path: 'temp-notebook.ipynb',
                    kernelPreference: { shouldStart: false, canStart: false }
                });
                console.log('context', context);
                const content = new NotebookPanel({
                    context,
                    //@ts-ignore
                    contentFactory,
                    mimeTypeService: editorServices.mimeTypeService,
                    rendermime
                });
                console.log('content', content);
                content.title.label = 'Untitled';
                content.title.closable = true;
                const widget = new MainAreaWidget({ content });
                widget.title.label = 'Temporary Notebook';
                app.shell.add(widget, 'main');
                if (args.activate !== false) {
                    app.shell.activateById(widget.id);
                }
                return widget;
            }
        });
        // Add the command to the palette.
        palette.addItem({ command: CommandIDs.createNew, category: 'Notebook' });
        // Add the command to the launcher.
        if (launcher) {
            launcher.add({
                command: CommandIDs.createNew,
                category: 'Notebook',
                rank: 1
            });
        }
    }
};
/**
 * Export the plugins as default.
 */
const plugins = [factory];
export default plugins;
//# sourceMappingURL=old.js.map